summaryrefslogtreecommitdiff
path: root/src/gui/trade.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/trade.h')
-rw-r--r--src/gui/trade.h9
1 files changed, 8 insertions, 1 deletions
diff --git a/src/gui/trade.h b/src/gui/trade.h
index 90c688c3..5d82f875 100644
--- a/src/gui/trade.h
+++ b/src/gui/trade.h
@@ -51,7 +51,12 @@ class TradeWindow : public Window, gcn::ActionListener
~TradeWindow();
/**
- * Add an item the trade window.
+ * Add money to the trade window.
+ */
+ void addMoney(int quantity);
+
+ /**
+ * Add an item to the trade window.
*/
void addItem(int index, int id, bool own, int quantity, bool equipment);
@@ -106,8 +111,10 @@ class TradeWindow : public Window, gcn::ActionListener
private:
gcn::Label *itemNameLabel;
gcn::Label *itemDescriptionLabel;
+ gcn::Label *moneyLabel;
gcn::Button *addButton, *okButton, *cancelButton, *tradeButton;
ScrollArea *myScroll, *partnerScroll;
+ gcn::TextField *moneyField;
bool ok_other, ok_me;
};